===============
collectionish
===============


.. image:: https://img.shields.io/pypi/v/collectionish.svg
        :target: https://pypi.python.org/pypi/collectionish

.. image:: https://img.shields.io/travis/leaprovenzano/collectionish.svg
        :target: https://travis-ci.com/leaprovenzano/collectionish

.. image:: https://readthedocs.org/projects/collectionish/badge/?version=latest
        :target: https://collectionish.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status



More python collection datatypes and ops for working with them.


* Free software: MIT license
* Documentation: https://collectionish.readthedocs.io.
* 